def add(x: int, y: int) -> int:
    """Adds two integers together.

    This is a simple example function used to demonstrate how to create
    and structure a Python package.

    Args:
        x (int): The first number to add.
        y (int): The second number to add.

    Returns:
        int: The sum of x and y.
    """
    return x + y
